@@ -1,6 +1,22 @@
+# vim: ft=bash
+
 PATH=$PWD/../src:$PATH
 export LC_ALL=C
 
+RED=$'\033[0;31m'
+GREEN=$'\033[0;32m'
+NC=$'\033[0m'  # No Color
+
+check_equal () {
+    echo -n "Testing \"$1\" = \"$2\": "
+    if [ "$1" = "$2" ]; then
+        echo "${GREEN}OK!${NC}"
+    else
+        echo "${RED}BAD${NC}"
+        return 1
+    fi
+}
+
 cleanup () {
     EXIT=$?
     # Errors are no longer fatal
